package com.composition.android.ad.csj.load.request

import android.content.Context
import com.bytedance.sdk.openadsdk.*
import com.composition.android.ad.csj.impl.CSJBannerAdSize
import com.composition.android.ad.csj.util.printAdFailInfo
import com.composition.android.ad.csj.util.printAdInfo
import com.composition.android.lib.ad.basic.AdResult
import com.composition.android.lib.ad.bean.AdUnitBean
import com.composition.android.lib.ad.interfaces.IAdFormatRequest
import kotlinx.coroutines.suspendCancellableCoroutine
import kotlin.coroutines.resume

/**
 * @classname:
 * @author: LiuXiaoLong
 * @date: 2022/9/13
 * description:穿山甲横幅广告加载类
 */
class CSJBannerRequestImpl : IAdFormatRequest {
    override suspend fun load(context: Context, adUnitBean: AdUnitBean): AdResult {
        return suspendCancellableCoroutine {
            val size = if (adUnitBean.adSize is CSJBannerAdSize) {
                (adUnitBean.adSize as CSJBannerAdSize).getAdSize()
            } else {
                600F to 90F
            }
            val adSlot = AdSlot.Builder()
                .setCodeId(adUnitBean.adUnitId)
                .setAdCount(1)
                .setImageAcceptedSize(600, 300)
                .setExpressViewAcceptedSize(size.first, size.second)
                .setAdLoadType(TTAdLoadType.LOAD)
                .build()

            TTAdSdk.getAdManager().createAdNative(context)
                .loadBannerExpressAd(adSlot, object : TTAdNative.NativeExpressAdListener {
                    override fun onError(p0: Int, p1: String?) {
                        printAdFailInfo(p0, p1)
                        if (it.isActive) {
                            it.resume(AdResult.Fail(adUnitBean, msg = p1 ?: "穿山甲横幅广告加载失败"))
                        }
                    }

                    override fun onNativeExpressAdLoad(p0: MutableList<TTNativeExpressAd>?) {
                        printAdInfo(adUnitBean)
                        if (it.isActive) {
                            if (p0.isNullOrEmpty().not()) {
                                it.resume(AdResult.Success(adBean = adUnitBean, adObject = p0?.get(0), msg = "穿山甲横幅广告加载成功"))
                            } else {
                                it.resume(AdResult.Fail(adUnitBean, msg = "穿山甲横幅广告加载失败, adList为空"))
                            }
                        }
                    }
                })
        }
    }
}